[GN] Fix "gn gen --ide=vs" to ignore bundle_data targets.

In order to keep the BUILD.gn more readable by avoiding conditionals,
Chromium defines bundle_data on every platforms (as in the absence of
create_bundle they are just no-op stamp targets).

Fix "gn gen --ide=vs" to ignore bundle_data targets but not the
create_bundle targets (as there should be no such targets on Windows).

BUG=595915

Review URL: https://codereview.chromium.org/1811203003

Cr-Original-Commit-Position: refs/heads/master@{#382197}
Cr-Mirrored-From: https://chromium.googlesource.com/chromium/src
Cr-Mirrored-Commit: a90c62f80a74f7abc647234f70ac596e86bf3dd2
diff --git a/tools/gn/visual_studio_writer.cc b/tools/gn/visual_studio_writer.cc
index 54a7bf2..801ea77 100644
--- a/tools/gn/visual_studio_writer.cc
+++ b/tools/gn/visual_studio_writer.cc
@@ -259,11 +259,12 @@
   writer.folders_.reserve(targets.size());
 
   for (const Target* target : targets) {
     // Skip actions and groups.
     if (target->output_type() == Target::GROUP ||
         target->output_type() == Target::COPY_FILES ||
         target->output_type() == Target::ACTION ||
-        target->output_type() == Target::ACTION_FOREACH) {
+        target->output_type() == Target::ACTION_FOREACH ||
+        target->output_type() == Target::BUNDLE_DATA) {
       continue;
     }
@@ -259,11 +259,12 @@
 
   for (const Target* target : targets) {
-    // Skip actions and groups.
+    // Skip actions, groups and bundle targets.
     if (target->output_type() == Target::GROUP ||
         target->output_type() == Target::COPY_FILES ||